Huachuang Security Python Library for Python
===================================================



Overview
--------

Huachuang Security Python Library SDK 1.0.3 . The package name is `finbull` to avoid conflict with previous versions. 


The SDK of this version is dependent on the third-party HTTP library `requests <https://github.com/kennethreitz/requests>`_ and `crcmod`. Install the SDK following the methods below. 


Installing
----------

Install the official release version through PIP (taking Linux as an example): 

.. code-block:: bash

    $ pip install finbull

You can also install the unzipped installer package directly: 

.. code-block:: bash

    $ sudo python setup.py install
    

Getting started
---------------

.. code-block:: bash

    $ import finbull as fb
    $ fb.__version__
